@@ -10,10 +10,12 @@ names exist, the first file will be taken.
 
 
 def is_show_full_errors():
+    """If true, show full python errors"""
     return os.environ.get("SHOW_FULL_ERRORS", "false").strip().lower() == "true"
 
 
 def mark_show_full_errors(val: bool = True):
+    """Change the show full python errors value"""
     assert val is not None
     os.environ["SHOW_FULL_ERRORS"] = str(val).lower()
 
